//
// PovRay scene file for a retro aircraft
//
// Author:   Hj. Malthaner
// Email:    hansjoerg.malthaner@gmx.de
// Date:   2015/11/07
//
// Web:      http://opengameart.org/users/varkalandar
//
// This file is available under the GNU general
// public license v2 or newer.
//
// http://www.gnu.org/licenses/gpl-2.0.html
//

#include "rand.inc"                

global_settings 
{
	assumed_gamma 2.2
  max_trace_level 240
}


light_source
{
	<-15, 25, -5>
	color rgb 1
  parallel
}

camera 
{
  orthographic 
	location <0, 0, -7.1>
  rotate <30, 0, 0>
  rotate <0, 45, 0>
	look_at <0, 0, 0>
  translate <0, 1, 0>
}

// sky
sphere
{
	0, 200

	texture 
	{
		pigment 
		{
			bozo
			color_map
			{
				[0.1 color rgb <0.8, 0.7, 1>]
				[0.9 color rgb <0.8, 0.7, 1>]
			}
			quick_color 0
			
			scale 0.01
		}
		normal
		{
			bozo 0.05
			scale 0.01
		}
		finish
		{
			ambient 0.04
			diffuse 0.3
			specular 0.3
			roughness 0.05
			reflection 0.05
		}    
	}
	hollow
}

#declare TEX_METAL =
texture
{
  pigment 
  {
    color rgb <1.0, 0.6, 0.3>
		quick_color 1
  }
  normal
  {
    bozo 0.1
    scale 0.5
  }
  finish
  {
    ambient 0.1
    diffuse 0.5
    specular 0.7
    roughness 0.05
    reflection 0.2
  }
}

#declare TEX_METAL_SILVER =
texture
{
  pigment 
  {
    color rgb <0.9, 0.95, 1.0>
		quick_color 1
  }
  normal
  {
    bozo 0.1
    scale 0.5
  }
  finish
  {               
    metallic
    ambient 0.05
    diffuse 0.8
    specular 0.5
    roughness 0.04  
    reflection 0.1
  }
}

#declare TEX_METAL_BLACK =
texture
{
  pigment 
  {
    color rgb <0.1, 0.1, 0.1>
		quick_color 1
  }
  normal
  {
    bozo 0.1
    scale 0.5
  }
  finish
  {               
    metallic
    ambient 0.05
    diffuse 0.8
    specular 0.5
    roughness 0.04  
    reflection 0.1
  }
}

#declare TEX_METAL_GLOW =
texture
{
  pigment 
  {
    color rgb <0.8, 0.1, 0.0>
		quick_color 1
  }
  normal
  {
    bozo 0.1
    scale 0.5
  }
  finish
  {
    ambient 0.1
    diffuse 0.1
    specular 0  
  }
}

// Background
box 
{
	<-6, -1, -5>,
	<6, -0.00001, 9>
	
	texture 
	{
		pigment 
		{
      color rgb 0
			quick_color <1, 0, 1>
			// quick_color 0
		}

		finish 
		{
			ambient 1
			diffuse 0
			specular 0
		}
	}
  
  rotate <0, 45, 0>
}

#declare O_HOUSING = 
union 
{
    lathe
    {
        cubic_spline
        
        7,
        
        <0.8, -1>, // end
        <0.8, 0>,
        <1, 4>,    // front, inner
        
        <1.4, 4>, // front, outer 
        <1.5, 2.5>,
        
        <0.8, 0>        
        <0.0, -0.9>        
    }         
     
    difference
    {
        cone
        {
            <0, 0, 0>, 0.90, <0, 1, 0>, 1.1 
        }
        cone
        {
            <0, -0.001, 0>, 0.89, <0, 1.001, 0>, 1.09 
        }
    
        translate <0, -0.4, 0>
    } 
     
     
    texture
    {
        TEX_METAL_SILVER
    }
}

#declare O_BLAST = 
box
{
    <-1, -10, -1>,
    <1, 0, 1>
    
    pigment { rgbt 1 } hollow
    interior
    {
        media
        { 
            emission 1
            density
            {
                spherical 
                density_map
                {
                    [0 rgb 0]
                    [0.3 rgb <0.2, 0, 0>]
                    [0.4 rgb <0.5, 0.5, 0>]
                    [0.6 rgb <0, 0.2, 1>]
                    [0.8 rgb <0.2, 1, 1>]
                    [1 rgb 1]     
                }
                                  
                                  
                turbulence 0.1                  
                scale <0.9, 7, 0.9>
                translate <0, -1, 0>
            }
        }    
    }
}

#declare O_FAN = 
union
{                

    // old nose
    /*
    sphere
    {
        0, 1
        
        scale <0.35, 1, 0.35>
        translate <0, 4.3, 0>
    }                        
    */
    
    lathe
    {
        quadratic_spline
        4,
        
        <1.1, -1>,
        <1.1, 0>,
        <0.5, 2.08>,
        <0, 2.72>
        
        translate <0, 2.2, 0>
    }         
    
                
    #local n=0;
    #while(n < 8)
    
        light_source
        {
            <sin(n*pi/4)*0.9, 4, cos(n*pi/4)*0.9>
            color rgb <0.1, 0.2, 1.4>
            // shadowless
            fade_power 2
            fade_distance 10
        }

    
    #local n=n+1;    
    #end
                          
    #local n=0;
    #while(n < 18)
    
    box
    {
        <-0.1, -0.01, 0>, 
        <0.1, 0.01, 1.05>
                       
        rotate <12, 0, 0>               
        rotate <0, 0, -35>               
                       
        rotate <0, n*360/18, 0>
        translate <0, 4.2, 0>                  
        texture
        {
            TEX_METAL_GLOW
        }
    }
        
    #local n=n+1;    
    #end              
                  
                  
    texture
    {
        TEX_METAL
    }
}

#declare O_TURBINE = 
union 
{
    object
    {
        O_HOUSING
    }                    
    
    object
    {
        O_FAN
    }        

    object
    {
        O_BLAST
    }        
                         
                         
    scale 0.5                         
                         
    translate <0, -2, 0>
    rotate <-90, 0, 0>
    
    translate <0, 2, 0>
}


#declare O_WING = 
intersection 
{
    sphere
    {
        0, 1
    }       
    
    box
    {
        <-1, 0, -1>
        <0, 1, 1>
    }               
    
    scale <3, 0.4, 1>
 
    texture
    {
        TEX_METAL_SILVER
    }
}

#declare O_BODY = 
union 
{                    
    intersection
    {
        sphere
        {
            0, 1
            
            scale <1, 1, 5>
        }
        box
        {
            <-2, 2, -6>
            <2, -2, 4>
        }               
    }
    
    sphere
    {
        0, 1
        
        scale <0.2, 1, 2>
        translate <0, 0.5, 2>
    }
                     
    object
    {
        O_WING      
        translate <-0.5, -0.3, 0>
        rotate <0, 30, 0>
        translate <0, 0, 1>
    }             
                 
    object
    {
        O_WING      
        translate <+0.5, -0.3, 0>
        rotate <0, 180-30, 0>
        translate <0, 0, 1>
    }             
    
    
    
                    
    // cockpit
    sphere
    {
        0, 1
        scale <0.9, 0.7, 2>
        translate <0, 0.3, -1.4>
        texture
        {
            TEX_METAL_BLACK
        }
    }                
                    
    texture
    {
        TEX_METAL_SILVER
    }
}


union
{
    object
    {
        O_BODY
        translate <0, 1.3, -1>
    }

    
    object
    {
        O_TURBINE 
        translate <-1.7, -0.6, -0.5>
    }


    object
    {
        O_TURBINE 
        translate <+1.7, -0.6, -0.5>
    }
    
    scale 0.8 
    
}
